# Generated by Django 5.2.6 on 2025-09-23 09:43

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("maintenance", "0002_cloudflaresite_maintenance_url"),
    ]

    operations = [
        migrations.AddField(
            model_name="cloudflaresite",
            name="include_subdomains",
            field=models.BooleanField(
                default=True, help_text="Apply maintenance rules to all subdomains (*.domain.com)"
            ),
        ),
        migrations.AddField(
            model_name="cloudflaresite",
            name="subdomain_list",
            field=models.TextField(
                blank=True,
                help_text="Comma-separated list of specific subdomains to include (e.g., api,www,app)",
            ),
        ),
    ]
