# Generated by Django 5.2.6 on 2025-09-23 08:14

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("maintenance", "0001_initial"),
    ]

    operations = [
        migrations.AddField(
            model_name="cloudflaresite",
            name="maintenance_url",
            field=models.URLField(
                blank=True,
                help_text="URL to redirect to during maintenance mode. If empty, uses default maintenance page.",
                max_length=500,
            ),
        ),
    ]
